Summary:        Panorama Tools GUI
Name:           hugin
Version:        2023.0.0
Release:        %mkrel 3
License:        GPLv2+
Group:          Graphics/Utilities
URL:            https://hugin.sourceforge.net/
Source0:        https://downloads.sourceforge.net/hugin/%{name}-%{version}.tar.bz2
Patch0:         hugin-2012.0.0-invalid-utf8.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(tclap)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(libpano13) >= 2.9.19
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(freeglut)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  boost-devel
BuildRequires:  wxgtk3.0-devel
BuildRequires:  libgomp-devel
BuildRequires:  vigra-devel
BuildRequires:  lapack-devel
BuildRequires:  desktop-file-utils
BuildRequires:  imagemagick
BuildRequires:  perl(Image::ExifTool)
BuildRequires:  swig
# contains deprecated distutils
BuildRequires:  python3-setuptools

Requires:       libpano13-tools >= 2.9.19
Requires:       enblend
Requires:       perl-Image-ExifTool
Requires:       make

%description
Hugin can be used to stitch multiple images together. The resulting image can
span 360 degrees. Another common use is the creation of very high resolution
pictures by combining multiple images.


%files -f %{name}.lang
%doc AUTHORS Changes.txt README TODO
%license COPYING*
%{_bindir}/*
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man?/*
%{_datadir}/applications/*.desktop
%{_iconsdir}/*.png
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/*/mimetypes/application-x-ptoptimizer-script.png
%{_datadir}/mime/packages/%{name}.xml
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/scalable/apps/ptbatcher.svg
%{_iconsdir}/hicolor/*/apps/ptbatcher.png
%{_metainfodir}/*.xml
%{python3_sitearch}/*

%prep
%autosetup -p1

%py3_shebang_fix \
src/hugin_script_interface/plugins-dev/*.py \
src/hugin_script_interface/*.py \
src/hugin_script_interface/plugins/*.py

# use system module
rm -rf CMakeModules/FindZLIB.cmake

%build
%cmake -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DENABLE_LAPACK=ON \
       -DBUILD_HSI=ON \
       -DUSE_GDKBACKEND_X11=ON
%cmake_build

%install
%cmake_install

%find_lang %{name}

# Menu icons
for i in {16,22,32,48}; do
	mkdir -p %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
	convert -resize $ix$i src/hugin1/hugin/xrc/data/hugin.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done
convert -resize 32x32 src/hugin1/hugin/xrc/data/hugin.png %{buildroot}%{_iconsdir}/%{name}.png

# menu entry
desktop-file-install --vendor="" \
  --remove-category="Application" \
  --add-category="Photography" \
  --add-category="Graphics" \
  --dir %{buildroot}%{_datadir}/applications \
  %{buildroot}%{_datadir}/applications/*


%changelog
* Fri Jan 12 2024 wally <wally> 2023.0.0-3.mga10
+ Revision: 2030542
- rebuild for boost 1.84.0

* Wed Dec 20 2023 daviddavid <daviddavid> 2023.0.0-2.mga10
+ Revision: 2020172
- rebuild for py3.12

* Sun Nov 26 2023 daviddavid <daviddavid> 2023.0.0-1.mga10
+ Revision: 2009690
- new version: 2023.0.0
- remove merged upstream patch

* Thu Sep 28 2023 daviddavid <daviddavid> 2022.0.0-3.mga10
+ Revision: 1991695
- add archlinux patch to fix build with exiv2 0.28
+ wally <wally>
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 2022.0.0-2.mga9
+ Revision: 1926480
- rebuild for boost 1.81.0

* Thu Dec 22 2022 daviddavid <daviddavid> 2022.0.0-1.mga9
+ Revision: 1925651
- new version: 2022.0.0

* Mon Dec 12 2022 ns80 <ns80> 2021.0.0-3.mga9
+ Revision: 1921043
- rebuild for new libtiff

* Wed Nov 09 2022 mrambo3501 <mrambo3501> 2021.0.0-2.mga9
+ Revision: 1904949
- revert to wxgtk3.0 to fix segfault at startup

* Tue Nov 08 2022 daviddavid <daviddavid> 2021.0.0-1.mga9
+ Revision: 1904783
- new version: 2021.0.0
- switch to wxgtk 3.2
- remove no more needed patches

* Tue Nov 01 2022 mrambo3501 <mrambo3501> 2020.0.0-21.mga9
+ Revision: 1901036
- rebuild for new lensfun
- BR wxgtk3.0 to fix segfault (taken from mga8 r1671536 mga#28025)

* Fri Jul 15 2022 wally <wally> 2020.0.0-20.mga9
+ Revision: 1868991
- rebuild for wxgtk 3.2.0

* Sun Jul 03 2022 wally <wally> 2020.0.0-19.mga9
+ Revision: 1867259
- rebuild for boost 1.79.0

* Sun Jun 12 2022 wally <wally> 2020.0.0-18.mga9
+ Revision: 1864099
- rebuild for wxgtk 3.1.7

* Thu Apr 14 2022 wally <wally> 2020.0.0-17.mga9
+ Revision: 1849895
- rebuild for wxgtk 3.1.6

* Tue Apr 05 2022 umeabot <umeabot> 2020.0.0-16.mga9
+ Revision: 1844100
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 wally <wally> 2020.0.0-15.mga9
+ Revision: 1774131
- rebuild for python3.10

* Sat Jan 15 2022 wally <wally> 2020.0.0-14.mga9
+ Revision: 1768512
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Tue Jan 04 2022 wally <wally> 2020.0.0-13.mga9
+ Revision: 1766825
- build with wxgtk3.1

* Mon Dec 27 2021 wally <wally> 2020.0.0-12.mga9
+ Revision: 1764519
- rebuild for openexr 3.1.3

* Sun Dec 19 2021 wally <wally> 2020.0.0-11.mga9
+ Revision: 1762654
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 2020.0.0-10.mga9
+ Revision: 1744640
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 2020.0.0-9.mga9
+ Revision: 1722970
- rebuild for boost 1.76.0

* Thu Mar 18 2021 neoclust <neoclust> 2020.0.0-8.mga9
+ Revision: 1704365
- Rebuild against python 3.9

* Wed Jan 13 2021 daviddavid <daviddavid> 2020.0.0-7.mga8
+ Revision: 1671536
- switch back to wxgtk3.0 to see if it fixes segfault (mga#28025)

* Wed Jan 13 2021 daviddavid <daviddavid> 2020.0.0-6.mga8
+ Revision: 1671492
- enforce GDK_BACKEND=x11 for Hugin as workaround for wxWidgets
  bug (not supporting wxGLCanvas on Wayland)
- add upstream patch to fix assert on calibrate_lens_gui startup

* Fri Jan 01 2021 wally <wally> 2020.0.0-5.mga8
+ Revision: 1667704
- rebuild for wxgtk pre 3.1.5 snapshot

* Thu Dec 31 2020 wally <wally> 2020.0.0-4.mga8
+ Revision: 1666768
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 2020.0.0-3.mga8
+ Revision: 1662010
- rebuild for boost 1.74.0

* Wed Dec 16 2020 neoclust <neoclust> 2020.0.0-2.mga8
+ Revision: 1658091
- Rebuild because of missing signature

* Tue Dec 15 2020 daviddavid <daviddavid> 2020.0.0-1.mga8
+ Revision: 1657812
- new version: 2020.0.0

* Wed Dec 02 2020 luigiwalser <luigiwalser> 2019.2.0-6.mga8
+ Revision: 1651353
- rebuild for glew

* Sat Sep 26 2020 tv <tv> 2019.2.0-5.mga8
+ Revision: 1630190
- rebuild for new libIlmImf

* Sun Aug 16 2020 wally <wally> 2019.2.0-4.mga8
+ Revision: 1614344
- rebuild for new wxgtk 3.1.4

* Sun May 03 2020 wally <wally> 2019.2.0-3.mga8
+ Revision: 1578064
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 2019.2.0-2.mga8
+ Revision: 1545042
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 daviddavid <daviddavid> 2019.2.0-1.mga8
+ Revision: 1483727
- new version: 2019.2.0
+ wally <wally>
- rebuild for boost 1.72.0
- build with new cmake macros

* Tue Nov 12 2019 wally <wally> 2019.0.0-6.mga8
+ Revision: 1459469
- rebuild for wxgtk 3.1.3

* Mon Sep 16 2019 tv <tv> 2019.0.0-5.mga8
+ Revision: 1442462
- rebuild for python-3.8

* Sun Sep 01 2019 daviddavid <daviddavid> 2019.0.0-4.mga8
+ Revision: 1436105
- port to Python 3

* Thu Jul 18 2019 wally <wally> 2019.0.0-3.mga8
+ Revision: 1422648
- rebuild with gtk3 enabled wxgtk 3.1.2

* Wed May 15 2019 daviddavid <daviddavid> 2019.0.0-2.mga7
+ Revision: 1397899
- patch to fix breakage caused by exiv2 0.27.1

* Sat Apr 13 2019 daviddavid <daviddavid> 2019.0.0-1.mga7
+ Revision: 1389666
- new version: 2019.0.0

* Mon Mar 11 2019 daviddavid <daviddavid> 2018.0.0-7.mga7
+ Revision: 1374216
- add missing build dependency on pkgconfig(sqlite3)

* Sun Dec 30 2018 daviddavid <daviddavid> 2018.0.0-6.mga7
+ Revision: 1347191
- add patch to fix build with exiv2 >= 0.27
+ luigiwalser <luigiwalser>
- rebuild for exiv2

* Tue Oct 16 2018 wally <wally> 2018.0.0-5.mga7
+ Revision: 1321045
- rebuild for new boost 1.68.0

* Tue Oct 16 2018 daviddavid <daviddavid> 2018.0.0-4.mga7
+ Revision: 1320922
- rebuild for new ilmbase and openexr 2.3.0

* Sun Sep 23 2018 umeabot <umeabot> 2018.0.0-3.mga7
+ Revision: 1298222
- Mageia 7 Mass Rebuild

* Sun May 27 2018 wally <wally> 2018.0.0-2.mga7
+ Revision: 1232417
- rebuild for openexr 2.2.1

* Sun Feb 04 2018 daviddavid <daviddavid> 2018.0.0-1.mga7
+ Revision: 1198786
- new version: 2018.0.0

* Sat Jan 13 2018 wally <wally> 2017.0.0-6.mga7
+ Revision: 1192562
- rebuild for new ilmbase

* Mon Dec 25 2017 wally <wally> 2017.0.0-5.mga7
+ Revision: 1184675
- rebuild for new boost

* Sun Dec 03 2017 daviddavid <daviddavid> 2017.0.0-4.mga7
+ Revision: 1180796
- rebuild for new glew 2.1.0

* Tue Nov 21 2017 tv <tv> 2017.0.0-3.mga7
+ Revision: 1178115
- rebuild for boost 1.65

* Sat Sep 23 2017 daviddavid <daviddavid> 2017.0.0-2.mga7
+ Revision: 1158135
- rebuild for new boost 1.64.0

* Wed Jul 19 2017 daviddavid <daviddavid> 2017.0.0-1.mga7
+ Revision: 1125321
- new version: 2017.0.0

* Tue Jun 20 2017 neoclust <neoclust> 2016.2.0-3.mga6
+ Revision: 1108011
- Rebuild against new exiv2

* Sat Jun 03 2017 akien <akien> 2016.2.0-2.mga6
+ Revision: 1106099
- Rebuild for wxgtk 3.0.3.1

* Mon Sep 19 2016 daviddavid <daviddavid> 2016.2.0-1.mga6
+ Revision: 1054156
- new version: 2016.2.0

* Thu Jun 02 2016 daviddavid <daviddavid> 2016.0.0-2.mga6
+ Revision: 1019815
- rebuild for wxgtk3.0 built with GTK2

* Wed Apr 13 2016 daviddavid <daviddavid> 2016.0.0-1.mga6
+ Revision: 1001127
- new version: 2016.0.0
- add BR pkgconfig(lcms2)

* Fri Jan 08 2016 luigiwalser <luigiwalser> 2015.0.0-7.mga6
+ Revision: 920537
- rebuild for lensfun

* Sat Dec 26 2015 daviddavid <daviddavid> 2015.0.0-6.mga6
+ Revision: 915187
- rebuild for new boost 1.60.0
- use new python macro

* Sat Sep 26 2015 daviddavid <daviddavid> 2015.0.0-5.mga6
+ Revision: 883831
- rebuild for new boost 1.59.0

* Wed Aug 26 2015 fwang <fwang> 2015.0.0-3.mga6
+ Revision: 869502
- rebuild for new glew

* Sat Aug 15 2015 ycantin <ycantin> 2015.0.0-2.mga6
+ Revision: 864907
- fix gomp br
- BR fftw3 : fix compilation error
- BR gomp : perf boost expected
+ shlomif <shlomif>
- Rebuild for checking something

* Wed Aug 12 2015 fwang <fwang> 2015.0.0-1.mga6
+ Revision: 863436
- use shipped icons
- br vigra
- 2015.0.0
+ daviddavid <daviddavid>
- rebuild for new boost-1.58.0

* Thu Jul 23 2015 akien <akien> 2014.0.0-2.mga6
+ Revision: 856370
- Rebuild for wxgtk with gtk3

* Wed Jun 24 2015 akien <akien> 2014.0.0-1.mga6
+ Revision: 842216
- Version 2014.0.0 final

* Mon Feb 09 2015 shlomif <shlomif> 2014.0.0-0.rc4.5.mga5
+ Revision: 814249
- move icons from /gnome/ to /Adwaita/.

* Wed Oct 15 2014 umeabot <umeabot> 2014.0.0-0.rc4.4.mga5
+ Revision: 750065
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2014.0.0-0.rc4.3.mga5
+ Revision: 680204
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 luigiwalser <luigiwalser> 2014.0.0-0.rc4.2.mga5
+ Revision: 670268
- rebuild for glew

* Tue Aug 26 2014 fwang <fwang> 2014.0.0-0.rc4.1.mga5
+ Revision: 667774
- update file list
- br Image-ExifTool
- bump requires
- 2014.0.0 rc4
+ luigiwalser <luigiwalser>
- rebuild for ilmbase and OpenEXR
+ pterjan <pterjan>
- Rebuild for new Python

* Thu May 01 2014 luigiwalser <luigiwalser> 2013.0.0-3.mga5
+ Revision: 619152
- rebuild for ilmbase

* Mon Feb 10 2014 dams <dams> 2013.0.0-2.mga5
+ Revision: 589011
- rebuild for new exiv2

* Wed Feb 05 2014 fwang <fwang> 2013.0.0-1.mga5
+ Revision: 583537
- 2013.0.0 (build with wxwidgets 3.0)

* Sat Oct 19 2013 umeabot <umeabot> 2013.0.0-0.rc2.2.mga4
+ Revision: 534432
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 fwang <fwang> 2013.0.0-0.rc2.1.mga4
+ Revision: 477853
- new version 2013.0.0_rc2

* Wed Jul 24 2013 sander85 <sander85> 2013.0.0-0.rc1.2.mga4
+ Revision: 457707
- Rebuild for new glew

* Wed Jul 10 2013 fwang <fwang> 2013.0.0-0.rc1.1.mga4
+ Revision: 452326
- 2013.0.0 rc1

* Wed Jun 05 2013 fwang <fwang> 2012.0.0-5.mga4
+ Revision: 437484
- fix invalid characters
- rebuild for new libpng

* Wed Apr 10 2013 malo <malo> 2012.0.0-4.mga3
+ Revision: 409458
- rebuild for boost 1.53

* Sat Jan 12 2013 umeabot <umeabot> 2012.0.0-3.mga3
+ Revision: 353374
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Thu Dec 20 2012 fwang <fwang> 2012.0.0-2.mga3
+ Revision: 333037
- rebuild for new boost

* Sun Dec 02 2012 fwang <fwang> 2012.0.0-1.mga3
+ Revision: 325044
- update file list
- br swig
- br lensfun
- new version 2012.0.0

* Sun Aug 19 2012 pterjan <pterjan> 2011.4.0-4.mga3
+ Revision: 282403
- Rebuild for new glew

* Wed Jul 25 2012 fwang <fwang> 2011.4.0-3.mga3
+ Revision: 274290
- add fedora patch to build with gcc 4.7
- rebuild for new glew

* Mon Jun 18 2012 fwang <fwang> 2011.4.0-2.mga3
+ Revision: 261643
- rebuild for new exiv

* Wed May 30 2012 fwang <fwang> 2011.4.0-1.mga3
+ Revision: 249720
- rebuild for new boost

* Fri Dec 30 2011 mikala <mikala> 2011.4.0-0.mga2
+ Revision: 189041
- Enable lapack support
- add ugly workaround to fix CXX flags (a ; is added after -pthread breaking it)
- Update tarball to 2011.4.0
- add lapack-devel as buildrequires
+ fwang <fwang>
- rebuild for new libtiff

* Mon Nov 28 2011 fwang <fwang> 2011.2.0-3.mga2
+ Revision: 173610
- rebuild for new boost

* Sun Oct 09 2011 fwang <fwang> 2011.2.0-2.mga2
+ Revision: 153424
- rebuild for new exiv2

* Mon Oct 03 2011 fwang <fwang> 2011.2.0-1.mga2
+ Revision: 151216
- update file list
- br tclap
- new version 2011.2.0
+ mikala <mikala>
- Switch to pkconfig()
- remove %%defattr() and %%clean section

* Thu Sep 15 2011 fwang <fwang> 2011.0.0-3.mga2
+ Revision: 143750
- add gentoo patch to build with libpng 1.5
- rebuild for new libpng
- br xmu
- rebuild for new boost

* Wed Jun 22 2011 fwang <fwang> 2011.0.0-1.mga2
+ Revision: 111936
- bump req
- new version 2011.0.0

* Fri Mar 04 2011 ahmad <ahmad> 2010.4.0-2.mga1
+ Revision: 63921
- don't skip rpath so that libs in %%_libdir/hugin/ can be picked when launching
  hugin

* Fri Feb 18 2011 mikala <mikala> 2010.4.0-1.mga1
+ Revision: 53485
- Update to 2010.4.0
- Fix file list
- Drop BuildRoot
- Drop mdk macros
- Fix BR
- imported package hugin


* Wed Dec 01 2010 Funda Wang <fwang@mandriva.org> 2010.2.0-2mdv2011.0
+ Revision: 604452
- rebuild for new exiv2

* Sat Oct 16 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.2.0-1mdv2011.0
+ Revision: 585891
- Updated to 2010.2.0 final.

* Thu Sep 16 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.2.0-0.rc1.1mdv2011.0
+ Revision: 579115
- Updated to 2010.2rc1.

* Mon Aug 23 2010 Funda Wang <fwang@mandriva.org> 2010.2.0-0.beta1.5mdv2011.0
+ Revision: 572268
- rebuild for new boost

* Thu Aug 05 2010 Funda Wang <fwang@mandriva.org> 2010.2.0-0.beta1.4mdv2011.0
+ Revision: 566096
- rebuild for new boost

* Tue Aug 03 2010 Funda Wang <fwang@mandriva.org> 2010.2.0-0.beta1.3mdv2011.0
+ Revision: 565565
- rebuild for new exiv2

  + Nicholas Brown <nickbrown@mandriva.org>
    - bump release
    - Make installable

* Thu Jul 22 2010 Nicholas Brown <nickbrown@mandriva.org> 2010.2.0-0.beta1.1mdv2011.0
+ Revision: 556922
- New Version

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - fix conditional for %%post scripts

* Sat Feb 13 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2009.4.0-1mdv2010.1
+ Revision: 505490
- new release 2009.4.0

* Mon Feb 08 2010 Anssi Hannula <anssi@mandriva.org> 2009.2.0-5mdv2010.1
+ Revision: 501882
- rebuild for new boost

* Wed Feb 03 2010 Funda Wang <fwang@mandriva.org> 2009.2.0-4mdv2010.1
+ Revision: 500328
- rebuild for new boost

* Sat Jan 16 2010 Funda Wang <fwang@mandriva.org> 2009.2.0-3mdv2010.1
+ Revision: 492239
- rebuild for new libjpeg v8

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 2009.2.0-2mdv2010.1
+ Revision: 484207
- Rebuild for new libexiv2

* Wed Sep 30 2009 Nicholas Brown <nickbrown@mandriva.org> 2009.2.0-1mdv2010.0
+ Revision: 451790
- new version

* Fri Aug 21 2009 Funda Wang <fwang@mandriva.org> 0.8.0-3mdv2010.0
+ Revision: 418880
- rebuild for new libboost

* Sat Jul 18 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.8.0-2mdv2010.0
+ Revision: 397069
- Update to 0.8.0 final
- Update to 0.8.0 final

* Sun Jun 21 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.0-0.rc4.1mdv2010.0
+ Revision: 387692
- new version
- rediff patch

* Tue Mar 10 2009 Nicholas Brown <nickbrown@mandriva.org> 0.8.0-0.beta2.1mdv2009.1
+ Revision: 353413
- new version

* Wed Feb 25 2009 Nicholas Brown <nickbrown@mandriva.org> 0.8.0-0.beta1.1mdv2009.1
+ Revision: 344700
- fix build dependancies
- new version

* Mon Dec 22 2008 Funda Wang <fwang@mandriva.org> 0.7.0-4mdv2009.1
+ Revision: 317401
- rebuild against new boost

* Fri Oct 24 2008 Nicholas Brown <nickbrown@mandriva.org> 0.7.0-3mdv2009.1
+ Revision: 296923
- rebuild
- fix requires

* Wed Oct 22 2008 Nicholas Brown <nickbrown@mandriva.org> 0.7.0-1mdv2009.1
+ Revision: 296523
- final release version.
  depend on make. #44648
  remove unused .so files, to remove (devel) dependancies.

* Mon Sep 15 2008 Nicholas Brown <nickbrown@mandriva.org> 0.7.0-0.rc6.1mdv2009.0
+ Revision: 284888
- new rc6

* Thu Sep 04 2008 Nicholas Brown <nickbrown@mandriva.org> 0.7.0-0.rc5.1mdv2009.0
+ Revision: 280482
- rc5
- forgot patch file
- rc4
  now using cmake
  patch for proper linking
  tidyup

  + Oden Eriksson <oeriksson@mandriva.com>
    - added a gcc43 patch (P0, from gentoo)
    - fix linkage (P1, from gentoo)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Sun Jan 27 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.7-0.beta4.1mdv2008.1
+ Revision: 158623
- pano13 support
- new version

* Sat Jan 12 2008 Austin Acton <austin@mandriva.org> 0.6.1-4mdv2008.1
+ Revision: 149791
- rebuild for boost

  + Thierry Vignaud <tv@mandriva.org>
    - drop old menu
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Sep 24 2007 Anne Nicolas <ennael@mandriva.org> 0.6.1-3mdv2008.0
+ Revision: 92452
- Fix BuilRequire
- increase release
- Fix menu
- import hugin


* Sat Sep 02 2006 Anssi Hannula <anssi@mandriva.org> 0.6.1-2mdv2007.0
- fix buildrequires

* Mon Aug 21 2006 Frederic Crozat <fcrozat@mandriva.com> 0.6.1-1mdv2007.0
- Release 0.6.1

* Sat Jul 29 2006 Couriousous <couriousous@mandriva.org> 0.6-1mdv2007.0
- mkrel
- XDG menu
- 0.6

* Sun Jan 14 2006 Sebastien Savarin <plouf@mandriva.org> 0.5.3mdk
- Fix Requires on enblend

* Sat Jan  7 2006 Couriousous <couriousous@mandriva.org> 0.5-2mdk
- Fix buildrequires ( danny at mailmij,org )

* Sat Dec 17 2005 Couriousous <couriousous@mandriva.org> 0.5-1mdk
- 0.5 final

* Sun Sep 25 2005 Couriousous <couriousous@mandriva.org> 0.5-0.rc2.1mdk
- rc2
- Requires pano12 ( for PTOptimizer )
- Requires enblend ( hugin use it to blend pictures )
- Remove old sift-related stuff

* Thu Sep  1 2005 Couriousous <couriousous@mandriva.org> 0.5-0.rc1.5mdk
- rebuild without glitz deps

* Sat Aug 20 2005 Couriousous <couriousous@mandriva.org> 0.5-0.rc1.4mdk
- Fix hugin on x86_64

* Fri Jul 08 2005 Couriousous <couriousous@mandriva.org> 0.5-0.rc1.3mdk
- Rebuild with wxGTK2.6 
- Build with unicode 
- Do not use -z with enblend

* Mon Jun 27 2005 Couriousous <couriousous@mandriva.org> 0.5-0.rc1.2mdk
- Rebuild with wxGTK2.5

* Sun Jun 12 2005 Frederic Crozat <fcrozat@mandriva.com> 0.5-0.rc1.1mdk 
- Release 0.5rc1

* Sat May 21 2005 Couriousous <couriousous@mandriva.org> 0.5-0.beta6.2mdk
- Work-around some wxGTK2.6 bug

* Sat May 21 2005 Couriousous <couriousous@mandriva.org> 0.5-0.beta6.1mdk
- Beta6
- Rebuild with wxGTK 2.6 

* Sun May 15 2005 Couriousous <couriousous@mandriva.org> 0.5-0.beta4.2mdk
- Rebuild with WxWidget 2.5

* Sun Mar 27 2005 Couriousous <couriousous@mandrake.org> 0.5-0.beta4.1mdk
- 0.5 beta4

* Wed Jan 26 2005 Couriousous <couriousous@mandrake.org> 0.4-0.20050126.1mdk
- Cvs sync
- Disable french locale since it doesn't build

* Tue Jan 04 2005 Couriousous <couriousous@mandrake.org> 0.4-0.20050104.1mdk
- Cvs sync
- Some spec clean
- Use automatic install
- Add locales
- Disable "de" locale, as it doesn't build

* Wed Dec 08 2004 Couriousous <couriousous@mandrake.org> 0.4-0.20041208.1mdk
- Cvs sync

* Sat Aug 28 2004 Guillaume Rousse <guillomovitch@mandrake.org> 0.4-0.20040725.2mdk
- fixed directory ownership (distlint)

* Thu Aug 05 2004 Guillaume Rousse <guillomovitch@mandrake.org> 0.4-0.20040725.1mdk
- update from Couriousous <couriousous@zarb.org>:
 - sync with CVS
 - drop patch0
 - split the patented and non-patented part in two package
- disabled parallel build
- fixed buildrequires

* Fri Jul 02 2004 Guillaume Rousse <guillomovitch@mandrake.org> 0.3-1mdk 
- contributed by Couriousous <couriousous@sceen.net>
